@@ -220,9 +220,9 @@ if [[ ${outputFiles} ]]; then
 	fi
 	if [[ ${doRhpkgContainerBuild} -eq 1 ]]; then
     echo "[INFO] Trigger container-build in current branch: rhpkg container-build ${scratchFlag}"
-    tmpfile=`mktemp` && rhpkg container-build ${scratchFlag} --nowait | tee 2>&1 $tmpfile
+    tmpfile=$(mktemp) && rhpkg container-build ${scratchFlag} --nowait | tee 2>&1 $tmpfile
     taskID=$(cat $tmpfile | grep "Created task:" | sed -e "s#Created task:##") && brew watch-logs $taskID | tee 2>&1 $tmpfile
-    ERRORS="$(egrep "image build failed" $tmpfile)" && rm -f $tmpfile
+    ERRORS="$(grep "image build failed" $tmpfile)" && rm -f $tmpfile
     if [[ "$ERRORS" != "" ]]; then echo "Brew build has failed:
 
 $ERRORS
@@ -232,9 +232,9 @@ $ERRORS
 else
 	if [[ ${forceBuild} -eq 1 ]]; then
     echo "[INFO] Trigger container-build in current branch: rhpkg container-build ${scratchFlag}"
-    tmpfile=`mktemp` && rhpkg container-build ${scratchFlag} --nowait | tee 2>&1 $tmpfile
+    tmpfile=$(mktemp) && rhpkg container-build ${scratchFlag} --nowait | tee 2>&1 $tmpfile
     taskID=$(cat $tmpfile | grep "Created task:" | sed -e "s#Created task:##") && brew watch-logs $taskID | tee 2>&1 $tmpfile
-    ERRORS="$(egrep "image build failed" $tmpfile)" && rm -f $tmpfile
+    ERRORS="$(grep "image build failed" $tmpfile)" && rm -f $tmpfile
     if [[ "$ERRORS" != "" ]]; then echo "Brew build has failed:
 
 $ERRORS
